@@ -69,6 +69,28 @@ static PspgThemeElement themedef[THEMEDEF_SIZE][2];
 
 static int current_themedef_bank = 0;
 
+static unsigned int rgbtBackground = 0x0;
+static unsigned int rgbtBackground2 = 0x0;
+static unsigned int rgbtCurrentLine = 0x0;
+static unsigned int rgbtCurrentLine2 = 0x0;
+static unsigned int rgbtForeground = 0x0;
+static unsigned int rgbtComment = 0x0;
+static unsigned int rgbtComment2 = 0x0;
+static unsigned int rgbtCyan = 0x0;
+static unsigned int rgbtOrange = 0x0;
+static unsigned int rgbtPink = 0x0;
+static unsigned int rgbtPurple = 0x0;
+static unsigned int rgbtRed = 0x0;
+static unsigned int rgbtYellow = 0x0;
+static unsigned int rgbtGrey = 0x0;
+static unsigned int rgbtMediumGrey = 0x0;
+static unsigned int rgbtSilver = 0x0;
+static unsigned int rgbtMediumBlue = 0x0;
+static unsigned int rgbtWhite = 0x0;
+static unsigned int rgbtBlueZodiac = 0x0;
+static unsigned int rgbtDarkYellow = 0x0;
+
+
 static PspgStyleDependency
 styledep(PspgThemeElements el)
 {
@@ -236,7 +258,7 @@ color_index_rgb(unsigned int rgb)
 
 #define RGB(r, g, b)		((((int)(r / 1000.0 * 255.0)) << 16) + (((int)(g / 1000.0 * 255.0)) << 8) + ((int)(b / 1000.0 * 255.0)))
 
-void
+static void
 deftheme(PspgThemeElements idx, PspgColor fg, PspgColor bg, int attr)
 {
 	memcpy(&themedef[idx][current_themedef_bank].fg, &fg, sizeof(PspgColor));
@@ -244,7 +266,7 @@ deftheme(PspgThemeElements idx, PspgColor fg, PspgColor bg, int attr)
 	themedef[idx][current_themedef_bank].attr = attr;
 }
 
-void
+static void
 deftheme_rgb(PspgThemeElements idx, unsigned int fg, unsigned int bg, int attr)
 {
 	PspgThemeElement *te = &themedef[idx][current_themedef_bank];
@@ -1673,6 +1695,77 @@ initialize_color_pairs(int theme, bool direct_color)
 			deftheme_rgb(PspgTheme_pattern_line_vertical_cursor, 0xeeeeee, 0x005f40, 0);
 			deftheme_rgb(PspgTheme_pattern_line_vertical_cursor_border, 0x0087af, 0x005f40, 0);
 			break;
+
+		case 24:
+			/* Dracula theme */
+			rgbtBackground = 0x282a36;
+			rgbtCurrentLine = 0x44475a;
+			rgbtForeground = 0xf8f8f2;
+			rgbtComment = 0x6272a4;
+			rgbtCyan = 0x8be9fd;
+			rgbtOrange = 0xffb86c;
+			rgbtPink = 0xff79c6;
+			rgbtPurple = 0xbd93f9;
+			rgbtRed = 0xff5555;
+			rgbtYellow = 0xf1fa8c;
+			rgbtGrey = 0x4e525a;
+			rgbtMediumGrey = 0x9b999c;
+			rgbtSilver = 0xbdbac5;
+			rgbtMediumBlue = 0x4b8fa9;
+			rgbtWhite = 0xffffff;
+			rgbtBlueZodiac = 0x696c7b;
+			rgbtDarkYellow = 0xc0c870;
+
+			rgbtBackground2 = 0x21222c;
+			rgbtCurrentLine2 = 0x363948;
+			rgbtComment2 = 0x586693;
+
+			deftheme_rgb(PspgTheme_background, rgbtForeground, rgbtBackground, 0);
+			deftheme_rgb(PspgTheme_data, rgbtForeground, rgbtBackground, 0);
+			deftheme_rgb(PspgTheme_border, rgbtMediumGrey, rgbtBackground, 0);
+			deftheme_rgb(PspgTheme_label, rgbtPurple, rgbtBackground, A_BOLD);
+			deftheme_rgb(PspgTheme_rownum, rgbtMediumGrey, rgbtBackground, 0);
+			deftheme_rgb(PspgTheme_recnum, rgbtPurple, rgbtBackground, A_BOLD);
+			deftheme_rgb(PspgTheme_footer, rgbtMediumGrey, rgbtBackground, 0);
+
+			deftheme_rgb(PspgTheme_cursor_data, rgbtForeground, rgbtCurrentLine, 0);
+			deftheme_rgb(PspgTheme_cursor_border, rgbtMediumGrey, rgbtCurrentLine, 0);
+			deftheme_rgb(PspgTheme_cursor_label, rgbtForeground, rgbtCurrentLine, 0);
+			deftheme_rgb(PspgTheme_cursor_rownum, rgbtForeground, rgbtCurrentLine, 0);
+			deftheme_rgb(PspgTheme_cursor_recnum, rgbtForeground, rgbtCurrentLine, 0);
+			deftheme_rgb(PspgTheme_cursor_footer, rgbtForeground, rgbtCurrentLine, 0);
+
+			deftheme_rgb(PspgTheme_scrollbar_arrows, rgbtSilver, rgbtBackground, 0);
+			deftheme_rgb(PspgTheme_scrollbar_background, rgbtBackground, rgbtBackground, 0);
+			deftheme_rgb(PspgTheme_scrollbar_slider, rgbtSilver, rgbtSilver, 0);
+			deftheme_rgb(PspgTheme_scrollbar_active_slider, rgbtSilver, rgbtSilver, 0);
+
+			deftheme_rgb(PspgTheme_title, rgbtForeground, rgbtBackground, A_BOLD);
+			deftheme_rgb(PspgTheme_status_bar, rgbtForeground, rgbtBackground, 0);
+			deftheme_rgb(PspgTheme_prompt_bar, rgbtForeground, rgbtBackground, 0);
+			deftheme_rgb(PspgTheme_info_bar, rgbtForeground, rgbtBackground, A_BOLD);
+			deftheme_rgb(PspgTheme_error_bar, rgbtRed, rgbtBackground, A_BOLD);
+			deftheme_rgb(PspgTheme_input_bar, rgbtBackground, rgbtForeground, 0);
+
+			deftheme_rgb(PspgTheme_bookmark, rgbtBackground, rgbtOrange, A_BOLD);
+			deftheme_rgb(PspgTheme_bookmark_border, rgbtMediumGrey, rgbtOrange, A_BOLD);
+			deftheme_rgb(PspgTheme_cursor_bookmark, rgbtOrange, rgbtCurrentLine, A_BOLD);
+
+			deftheme_rgb(PspgTheme_cross_cursor, rgbtWhite, rgbtBlueZodiac, 0);
+			deftheme_rgb(PspgTheme_cross_cursor_border, rgbtMediumGrey, rgbtBlueZodiac, 0);
+
+			deftheme_rgb(PspgTheme_selection, rgbtForeground, rgbtComment, 0);
+			deftheme_rgb(PspgTheme_cursor_selection, rgbtForeground, rgbtComment, A_REVERSE);
+
+			deftheme_rgb(PspgTheme_pattern, rgbtBackground, rgbtYellow, A_BOLD);
+			deftheme_rgb(PspgTheme_pattern_nohl, rgbtBackground, rgbtYellow, A_BOLD);
+			deftheme_rgb(PspgTheme_pattern_line, rgbtCurrentLine, rgbtYellow, 0);
+			deftheme_rgb(PspgTheme_pattern_line_border, rgbtMediumGrey, rgbtYellow, 0);
+			deftheme_rgb(PspgTheme_pattern_cursor, rgbtWhite, rgbtCurrentLine, A_BOLD);
+
+			deftheme_rgb(PspgTheme_pattern_line_vertical_cursor, rgbtBackground, rgbtDarkYellow, 0);
+			deftheme_rgb(PspgTheme_pattern_line_vertical_cursor_border, rgbtMediumGrey, rgbtDarkYellow, 0);
+			break;
 	}
 
 	current_themedef_bank = 1;
@@ -1792,6 +1885,23 @@ initialize_color_pairs(int theme, bool direct_color)
 			deftheme_rgb(PspgTheme_selection, 0x090909, 0xc0c0c0, 0);
 			deftheme_rgb(PspgTheme_cursor_selection, 0xeeeeee, 0x181717, 0);
 
+			has_odd_themedef = true;
+			break;
+
+		case 24:
+			/* Dracula theme */
+			deftheme_rgb(PspgTheme_data, rgbtForeground, rgbtBackground2, 0);
+			deftheme_rgb(PspgTheme_border, rgbtMediumGrey, rgbtBackground2, 0);
+			deftheme_rgb(PspgTheme_label, rgbtPurple, rgbtBackground2, A_BOLD);
+
+			deftheme_rgb(PspgTheme_cursor_data, rgbtForeground, rgbtCurrentLine2, 0);
+			deftheme_rgb(PspgTheme_cursor_border, rgbtMediumGrey, rgbtCurrentLine2, 0);
+			deftheme_rgb(PspgTheme_cursor_label, rgbtForeground, rgbtCurrentLine2, 0);
+			deftheme_rgb(PspgTheme_cursor_rownum, rgbtForeground, rgbtCurrentLine2, 0);
+
+			deftheme_rgb(PspgTheme_selection, rgbtForeground, rgbtComment2, 0);
+			deftheme_rgb(PspgTheme_cursor_selection, rgbtForeground, rgbtComment2, A_REVERSE);
+
 			has_odd_themedef = true;
 			break;
 	}
